# What's Changed

1. 新增: 支持接入个人微信（WeChatPadPro）替换 gewechat 方式。
2. 新增：接入 PPIO 派欧云
3. 新增：支持接入 Minimax TTS
3. ‼️修复：Docker 下重启 AstrBot 会导致 astrbot 容器进程退出的问题。
4. 优化：速率限制功能
5. 优化：QQ 和 Telegram 下，群聊的 @ 信息也将发送给模型以获得更好的回复、QQ 支持 @ 全体成员的解析。
6. 优化：WebUI 配置项支持代码编辑器模式！
7. 优化：语音组件将单独发送以保证全平台兼容性
8. 优化：QQ 下，屏蔽 QQ 管家(qq=2854196310) 的所有消息。